@@ -1,6 +1,5 @@
 from pygments.token import Keyword, Name, Comment, String, Error, \
-    Number, Operator, Generic, Token, Whitespace, Punctuation, Text, \
-    Literal
+    Number, Operator, Generic, Token, Whitespace, Punctuation, Text
 
 from purdy.parser import FoldedCodeLine, token_ancestor
 
@@ -69,6 +68,9 @@ class UrwidColourizer:
 
         # add miscellaneous other palette items
         urwid_palette.extend([
+            ('reverse', 'black', 'white', '', 'black', 'white'),
+            ('bold', 'white,bold', '', '', 'white,bold', ''),
+            ('title', 'white,underline', '', '', 'white,underline', ''),
             ('folded', 'white', '', '', 'white', ''),
             ('line_number', 'dark gray', '', '', 'dark gray', ''),
             ('empty', '', '', '', '', ''),
