@@ -10,6 +10,10 @@ from copy import deepcopy
 from purdy.colour import COLOURIZERS
 from purdy.parser import FoldedCodeLine, parse_source
 
+#import logging
+#logging.basicConfig(filename='debug.log', level=logging.DEBUG)
+#logger = logging.getLogger()
+
 # =============================================================================
 
 class Code:
@@ -205,6 +209,25 @@ class Code:
 
         return self
 
+    def subset(self, start, end):
+        """Returns a new Code object containing just the subset of lines
+        identified in this call
+
+        :param start: line number of the listing to start the subset at.
+                      1-indexed
+        :param end: line number to finish the subset on, inclusive.  1-indexed.
+
+        :returns: Code object
+        """
+        code = deepcopy(self)
+        if end < start:
+            raise AttributeError('Value of end must be bigger than start')
+
+        lines = self.source.split('\n')
+        lines = lines[start - 1:end]
+        code.source = '\n'.join(lines)
+        return code
+
 # -----------------------------------------------------------------------------
 
 class RenderHook:
@@ -280,7 +303,7 @@ class Listing:
                 raise IndexError('position is 1-indexed, 0 is invalid')
 
             if original < 0:
-                raise IndexError( (f'position {original} translated to'
+                raise IndexError( (f'position {original} translated to '
                     f'{position}, is outside range 1-{size}') )
 
             raise IndexError(f'position {position} outside range 1-{size}')
